#!/usr/bin/python
import xmlrpclib

class Groups:
    """ keep track of existing and wanted groups """
    def __init__(self):
        self.groups = {}  # wanted groups
        self.existing_groups = {} # existing groups

    def add(self, name, desc):
        """ add wanted group """
        self.groups[name] = desc

    def download(self, client, key):
        """ update list of existing groups from SUSE Manager API """
        existing_groups = client.systemgroup.listAllGroups(key)
        self.existing_groups = {g['name'] : g for g in existing_groups}

    def upload(self, client, key):
        """ create all wanted groups in SUSE Manager API """
        self.download(client, key)

        for group, desc in self.groups.items():
            if group not in self.existing_groups:
                client.systemgroup.create(key, group, desc)

        self.download(client, key) # refresh data of newly created groups

    def get_attr(self, name, attr):
        """ get attribute of existing group """
        return self.existing_groups[name][attr]

    def get_id(self, name):
        """ get id of existing group """
        return self.get_attr(name, 'id')

    def get_existing(self):
        """ get list of existing groups """
        return self.existing_groups.keys()
